
<template>
  <view-grid
    ref="grid"
    :columns="columns"
    :detail="detail"
    :editFormFields="editFormFields"
    :editFormOptions="editFormOptions"
    :searchFormFields="searchFormFields"
    :searchFormOptions="searchFormOptions"
    :table="table"
    :extend="extend"
  >
  </view-grid>
</template>
    <script>
import extend from "@/extension/basic/locationInfo.js";
import { ref, defineComponent } from "vue";
export default defineComponent({
  setup() {
    const table = ref({
      key: "id",
      footer: "Foots",
      cnName: "货位信息",
      name: "locationInfo",
      url: "/LocationInfo/",
      sortName: "id",
    });
    const editFormFields = ref({
      row: "",
      column: "",
      layer: "",
      depth: "",
      locationType: "",
      locationStatus: "",
      enalbeStatus: "",
      remark: "",
    });
    const editFormOptions = ref([
      [
        {
          title: "货位行",
          required: true,
          field: "row",
          type: "string",
        },
        {
          title: "货位列",
          required: true,
          field: "column",
          type: "string",
        },
        {
          title: "货位层",
          required: true,
          field: "layer",
          type: "string",
        },
        {
          title: "货位深度",
          required: true,
          field: "depth",
          type: "string",
        },
      ],
      [
        { title: "货位类型", required: true, field: "locationType", type: "string" },
        {
          title: "货位状态",
          required: true,
          field: "locationStatus",
          type: "string",
        },
        {
          title: "禁用状态",
          required: true,
          field: "enalbeStatus",
          type: "string",
        },
        {
          title: "区域主键",
          required: true,
          field: "areaId",
          type: "string",
        },
      ],
      [
      {
          title: "巷道编号",
          required: true,
          field: "roadwayNo",
          type: "string",
        },
      ]
    ]);
    const searchFormFields = ref({
      locationCode: "",
      roadwayNo: "",
    });
    const searchFormOptions = ref([
      [
        { title: "货位编号", field: "locationCode" },
        { title: "巷道编号", field: "roadwayNo" },
      ],
    ]);
    const columns = ref([
      {
        field: "id",
        title: "Id",
        type: "int",
        width: 90,
        hidden: true,
        readonly: true,
        require: true,
        align: "left",
      },
      {
        field: "areaId",
        title: "区域主键",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "locationCode",
        title: "货位编号",
        type: "string",
        width: 150,
        align: "left",
      },
      {
        field: "locationName",
        title: "货位名称",
        type: "string",
        width: 150,
        align: "left",
      },
      {
        field: "roadwayNo",
        title: "巷道编号",
        type: "decimal",
        width: 90,
        align: "left",
      },
      {
        field: "row",
        title: "货位行",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "column",
        title: "货位列",
        type: "int",
        width: 120,
        align: "left",
      },
      {
        field: "layer",
        title: "货位层",
        type: "string",
        width: 200,
        align: "left",
      },
      {
        field: "depth",
        title: "货位深度",
        type: "string",
        width: 180,
        align: "left",
      },
      {
        field: "locationType",
        title: "货位类型",
        type: "string",
        width: 120,
        align: "left",
      },
      {
        field: "locationStatus",
        title: "货位状态",
        type: "string",
        width: 200,
        align: "left",
      },
      {
        field: "enalbeStatus",
        title: "禁用状态",
        type: "string",
        width: 180,
        align: "left",
      },
      {
        field: "creater",
        title: "创建人",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "createDate",
        title: "创建时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "modifier",
        title: "修改人",
        type: "string",
        width: 100,
        align: "left",
      },
      {
        field: "modifyDate",
        title: "修改时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "remark",
        title: "备注",
        type: "string",
        width: 100,
        align: "left",
      },
    ]);
    const detail = ref({
      cnName: "#detailCnName",
      table: "",
      columns: [],
      sortName: "",
    });
    return {
      table,
      extend,
      editFormFields,
      editFormOptions,
      searchFormFields,
      searchFormOptions,
      columns,
      detail,
    };
  },
});
</script>
    